Module startup_error

Module startup_error 

Classification of fatal startup failures into a log line plus a sentence for the error screen.

Enums

StartupError
Why the runtime could not reach a playable state.