Module state

Module state 

The App value a host constructs, starts, and steps. The App value: a world plus the loop state that drives it.

Structs

App
The application: a world plus the loop state that drives it.