Model

Struct Model 

pub struct Model {
    pub asset_id: AssetId,
    pub meshes: Vec<SubMeshRef>,
}
An ordered list of sub-meshes, each with its own material.

Use via the model field on a Prop instead of mesh. Each sub-mesh is drawn with its own material, all sharing the prop’s transform.

Each mesh must name a Mesh or ProceduralMesh asset present in the scene. material may be empty to use the default material.

Fields

asset_id: AssetId

Asset identity; injected via inject_name. Not part of args.

meshes: Vec<SubMeshRef>

Ordered list of sub-meshes that make up this model.