Classification of fatal startup failures into a log line plus a sentence for the error screen.
Enums
- Startup
Error - Why the runtime could not reach a playable state.
Classification of fatal startup failures into a log line plus a sentence for the error screen.